<h1> SQLSERVER PYODBC Module </h1>

##### Installation

````
pip install sqlserver
````

##### Usage

````
import sqlserver
db = sqlserver.sqlserver('yourconnectionstring')

db.(whateverfunctions in the modules)
returns data
````

###### Copyright ADGSTUDIOS 2021
